{% if filetype_loop == 0 %}VRF,Instance,Area,Interface,Neighbor,Neighbor Address,Neighbor Router ID,Index,Priority,State,Dead Time,Total Retransmissions,Uptime
{%-     for vrf in to_parse_ip_ospf_neighbor_detail %}
{%-         for address_family in to_parse_ip_ospf_neighbor_detail[vrf].address_family %}
{%-             for instance in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance %}
{%-                 for area in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas %}
{%-                     for interface in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces %}
{%-                         for neighbor in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors %}
{{ vrf }},{{ instance }},{{ area }},{{ interface }},{{ neighbor }},{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].address }},{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].neighbor_router_id }},{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].index | replace(",","") }},{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].priority }},{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].state }},{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].dead_timer }},{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].statistics.total_retransmission }},{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].uptime }}
{%-                         endfor %}
{%-                     endfor %}
{%-                 endfor %}
{%-             endfor %}
{%-         endfor %}
{%-     endfor %}
{%- else %}
{%-     if filetype_loop == 1 %}
# Show IP OPSF Neighbor Detail
| VRF | Instance | Area | Interface | Neighbor | Neighbor Address | Neighbor Router ID | Index | Priority | State | Dead Time | Total Retransmissions | Uptime |
| --- | -------- | ---- | --------- | -------- | ---------------- | ------------------ | ----- | -------- | ----- | --------- | --------------------- | ------ |
{%-         for vrf in to_parse_ip_ospf_neighbor_detail %}
{%-             for address_family in to_parse_ip_ospf_neighbor_detail[vrf].address_family %}
{%-                 for instance in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance %}
{%-                     for area in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas %}
{%-                         for interface in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces %}
{%-                             for neighbor in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors %}
| {{ vrf }} | {{ instance }} | {{ area }} | {{ interface }} | {{ neighbor }} | {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].address }} | {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].neighbor_router_id }} | {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].index | replace(",","") }} | {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].priority }} | {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].state }} | {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].dead_timer }} | {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].statistics.total_retransmission }} | {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].uptime }} |
{%-                             endfor %}
{%-                         endfor %}
{%-                     endfor %}
{%-                 endfor %}
{%-             endfor %}
{%-         endfor %}
{%-     else %}
{%-         if filetype_loop == 2 %}
<html>
<head>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/colreorder/1.5.4/js/dataTables.colReorder.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.colVis.min.js"></script>
    <script src="https://cdn.datatables.net/keytable/2.6.4/js/dataTables.keyTable.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.3.3/js/dataTables.select.min.js"></script>
    <script src="https://cdn.datatables.net/fixedheader/3.1.9/js/dataTables.fixedHeader.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/fixedheader/3.1.9/css/fixedHeader.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/select/1.3.3/css/select.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/keytable/2.6.4/css/keyTable.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.4/css/jquery.dataTables.min.css">
</head>
<body>
<h1>Show IP OSPF Neighbor Detail</h1>
<table id = "ospf">
  <thead>
  <tr>
    <th>VRF</th>
    <th>Instance</th>
    <th>Area</th>
    <th>Interface</th>
    <th>Neighbor</th>
    <th>Neighbor ID</th>
    <th>Neighbor Address</th>
    <th>Neighbor Router ID</th>
    <th>Index</th>
    <th>Priority</th>
    <th>State</th>
    <th>Dead Time</th>
    <th>Total Retransmissions</th>
    <th>Uptime </th>
  </tr>
  </thead>
  <tbody>
{%-             for vrf in to_parse_ip_ospf_neighbor_detail %}
{%-                 for address_family in to_parse_ip_ospf_neighbor_detail[vrf].address_family %}
{%-                     for instance in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance %}
{%-                         for area in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas %}
{%-                             for interface in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces %}
{%-                                 for neighbor in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors %}
<tr>
    <td>{{ vrf }}</td>
    <td>{{ instance }}</td>
    <td>{{ area }}</td>
    <td>{{ interface }}</td>
    <td>{{ neighbor }}</td>
    <td>{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].address }}</td>
    <td>{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].neighbor_router_id }}</td>
    <td>{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].index | replace(",","") }}</td>
    <td>{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].priority }}</td>
    <td>{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].state }}</td>
    <td>{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].dead_timer }}</td>
    <td>{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].statistics.total_retransmission }}</td>
    <td>{{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].uptime }}</td>
  </tr>
{%-                                 endfor %}
{%-                             endfor %}
{%-                         endfor %}
{%-                     endfor %}
{%-                 endfor %}
{%-             endfor %}
  <tbody>
</table>
<script type = "text/javascript">
  $(document).ready(function(){
    $('#ospf thead tr')
    .clone(true)
    .addClass('filters')
    .appendTo('#ospf thead');

    var table = $('#ospf').DataTable({
        keys: true,
        dom: 'Bfrtip',
        lengthMenu: [
            [ 10, 25, 50, -1 ],
            [ '10 rows', '25 rows', '50 rows', 'Show all' ]
        ],
        buttons: [
        'pageLength','colvis','copy', 'csv', 'excel', 'pdf', 'print'
        ],
        colReorder: true,
        select: true,            
        orderCellsTop: true,
        fixedHeader: true,
        initComplete: function () {
        var api = this.api();

        // For each column
        api
            .columns()
            .eq(0)
            .each(function (colIdx) {
                // Set the header cell to contain the input element
                var cell = $('.filters th').eq(
                    $(api.column(colIdx).header()).index()
                );
                var title = $(cell).text();
                $(cell).html('<input type="text" placeholder="' + title + '" />');

                // On every keypress in this input
                $(
                    'input',
                    $('.filters th').eq($(api.column(colIdx).header()).index())
                )
                    .off('keyup change')
                    .on('keyup change', function (e) {
                        e.stopPropagation();

                        // Get the search value
                        $(this).attr('title', $(this).val());
                        var regexr = '({search})'; //$(this).parents('th').find('select').val();

                        var cursorPosition = this.selectionStart;
                        // Search the column for that value
                        api
                            .column(colIdx)
                            .search(
                                this.value != ''
                                    ? regexr.replace('{search}', '(((' + this.value + ')))')
                                    : '',
                                this.value != '',
                                this.value == ''
                            )
                            .draw();

                        $(this)
                            .focus()[0]
                            .setSelectionRange(cursorPosition, cursorPosition);
                    });
            });
    },
});
});        
</script>
</body></html>
{%-         else %}
# Show IP OSPF Neighbor Detail
{%-             for vrf in to_parse_ip_ospf_neighbor_detail %}
{%-                 for address_family in to_parse_ip_ospf_neighbor_detail[vrf].address_family %}
{%-                     for instance in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance %}
## {{ vrf }} Instance: {{ instance }}
{%-                         for area in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas %}
### Area: {{ area }}</td>
{%-                             for interface in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces %}
#### Interface: {{ interface }}</td>
{%-                                 for neighbor in to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors %}
##### Neighbor: {{ neighbor }}
###### Address: {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].address }}
###### Router ID: {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].neighbor_router_id }}
###### Index: {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].index | replace(",","") }}
###### Priority: {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].priority }}
###### State: {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].state }}
###### Dead Timer: {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].dead_timer }}
###### Total Retransmissions: {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].statistics.total_retransmission }}
###### Uptime: {{ to_parse_ip_ospf_neighbor_detail[vrf].address_family[address_family].instance[instance].areas[area].interfaces[interface].neighbors[neighbor].uptime }}
{%-                                 endfor %}
{%-                             endfor %}
{%-                         endfor %}
{%-                     endfor %}
{%-                 endfor %}
{%-             endfor %}
{%-         endif %}
{%-     endif %}
{%- endif %}